#!/usr/bin/env perl
# $Id: doomvox.pl,v 1.6 2021/03/15 02:44:50 dpchrist Exp $
# Adapted from Joseph Brenner's solution
# Public Domain.
#
# https://github.com/doomvox/raku-study/blob/main/bin/2021feb28/pcre_regex_to_append_path_non_redundantly.t

use strict;
use warnings;

use Data::Dumper;
use File::Basename;
use File::Slurp;
use Getopt::Long;

my $base	= basename $0;

die "Usage: $base FILE\n" unless @ARGV == 1;

my $file	= shift;

my $in		= read_file($file);

my $replace	= ':/usr/local/bin';

## a zero-width pattern that matches only if there's 
## no /usr/local/bin already in the given string
my $pattern =
  qr{
      ^ 
      [^=]*?   =  \s+   # Begin after  'Defaults secure_path = '
      (?!       #  A zero-width negative lookahead assertion.
	(?:     
	  #            \s*      # not needed?
	  [^:]* 
	  : 
	)*       
	/usr/local/bin
	(?: 
	  #            \s+ |   #  not needed
	  :   | 
	  $    ) 
      )
      .*  ## matches *everything* but only if the negative lookahead does not match
      \K  ## keeps *everything*, prevents s/// from removing anything from the existing string
      $
  }x;

(my $out = $in) =~ s{ $pattern }{$replace}x;

print $out;
