#!/usr/bin/env perl
# $Id: dpchrist.pl,v 1.18 2021/03/15 02:44:50 dpchrist Exp $
# By David Paul Christensen dpchrist@holgerdanske.com
# Public Domain.
#
# https://github.com/doomvox/raku-study/blob/main/bin/2021feb28/pcre_regex_to_append_path_non_redundantly.t

use strict;
use warnings;

use Data::Dumper;
use File::Basename;
use File::Slurp;
use Getopt::Long;

my $base	= basename $0;
my $debug	= undef;

sub _d { warn((caller(0))[2], $", Data::Dumper->Dump(@_)) if $debug }

GetOptions('debug|d' => \$debug)
    or die "ERROR $base processing arguments";

die "Usage: $base [--debug|-d] FILE\n" unless @ARGV == 1;

my $file = shift;

my @in = read_file($file);
_d [\@in], [qw(*in)];

my @out;

my $delimiter	= ':';
my $newline	= "\n";
my $comp	= '/usr/local/bin';
my $rx		= qr(^(\s*Defaults[\\\s]+secure_path[\\\s]*=[\\\s]*.*?)((?:[\\\s]*#.*)?\n$))s;

for (my $i = 0; $i < @in; $i++) {
    my $line = $in[$i];
    _d [$i], [qw(i)]; _d [$line], [qw(line)];
    while ($i < @in && $line =~ m{\\$}s) {
	$line .= $in[++$i];
	_d [$i], [qw(i)]; _d [$line], [qw(line)];
    }
    if ( $line !~ /[^\w\/]$comp[^\w\/]/s && $line =~ $rx) {
	my $front = $1;		 _d [$front], [qw(front)];
	my $back  = $2;		 _d [$back ], [qw(back )];
	push @out, $front . $delimiter . $comp . $back;
	_d [$out[-1]], [qw(out)];
    } else {
	push @out, $line;
	_d [$out[-1]], [qw(out)];
    }
}
_d [\@out], [qw(*out)];

print @out;
